#[non_exhaustive]pub enum PointCloudError {
InvalidMaxPoints {
field: String,
configured: usize,
hard_maximum: usize,
},
NotArray {
field: String,
},
Empty {
field: String,
},
TooManyPoints {
field: String,
actual: usize,
maximum: usize,
},
InvalidPoint {
field: String,
index: usize,
source: CoordinateError,
},
SerializedSizeExceeded {
field: String,
actual: usize,
maximum: usize,
},
Canonicalization {
field: String,
source: CoordinateError,
},
}Expand description
Errors produced by point-cloud validation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidMaxPoints
The configured maximum was outside the supported range.
NotArray
The value was not a JSON array.
Empty
The cloud contained no points.
TooManyPoints
The cloud exceeded its configured point count.
InvalidPoint
One point was malformed or outside the coordinate ranges.
SerializedSizeExceeded
The canonical serialized cloud exceeded the storage safety limit.
Canonicalization
Canonical coordinate conversion failed.